==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/sv-SE/admin/categories/general.php <==
<?php

return array(
    'asset_categories' 					=> 'Kategorier',
    'category_name'  					=> 'Kategorinamn',
    'checkin_email'                     => 'Skicka e-post till användaren vid incheckning / utcheckning.',
    'checkin_email_notification'        => 'Den här användaren kommer att skickas ett mail vid incheckning / utcheckning.',
    'clone'                             => 'Klona kategori',
    'create'  							=> 'Skapa kategori',
    'edit'                              => 'Redigera kategori',
    'eula_text'							=> 'Kategori EULA',
    'eula_text_help'					=> 'I detta fält kan du anpassa dina licensavtal för slutanvändare, EULA, för vissa typer av tillgångar. Om du bara har ett licensavtal för alla dina tillgångar, kan du markera rutan nedan för att använda standardlicensavtalet.',
    'name'                              => 'Kategorinamn',
    'require_acceptance'				=> 'Kräv att användare bekräftar mottagande av tillgångar i denna kategori.',
    'required_acceptance'				=> 'Användaren kommer att få e-post med en länk för att bekräfta mottagande av detta objekt.',
    'required_eula'						=> 'Användaren kommer att få e-post med en kopia av licensavtalet, EULA',
    'no_default_eula'					=> 'Ingen standard-licensavtal, EULA, hittades. Lägg till en under Inställningar.',
    'update'  							=> 'Uppdatera kategori',
    'use_default_eula'					=> 'Använd <a href="#" data-toggle="modal" data-target="#eulaModal">standard-licensavtal, EULA</a> istället.',
    'use_default_eula_disabled'			=> '<del>Använd den primära licensavtalet, EULA:n, istället.</del> Inget primärt licensavtal, EULA, är satt. Vänligen lägg till en under Inställningar.',

);

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/sv-SE/admin/categories/general.php <==
<?php

return array(
    'asset_categories' 					=> 'Tillgångskategorier',
    'category_name'  					=> 'Kategorinamn',
    'checkin_email'                     => 'Skicka e-post till användaren vid incheckning/utcheckning.',
    'checkin_email_notification'        => 'Den här användaren kommer att få e-post vid incheckning/utcheckning.',
    'clone'                             => 'Kopiera kategori',
    'create'  							=> 'Skapa kategori',
    'edit'                              => 'Redigera kategori',
    'email_will_be_sent_due_to_global_eula' => 'Ett e-postmeddelande kommer att skickas till användaren eftersom det globala användaravtalet (EULA) används.',
    'email_will_be_sent_due_to_category_eula' => 'Ett e-postmeddelande kommer att skickas till användaren eftersom ett användaravtal (EULA) är inställt för denna kategori.',
    'eula_text'							=> 'EULA-kategori',
    'eula_text_help'					=> 'I detta fält kan du anpassa dina licensavtal för slutanvändare, EULA, för vissa typer av tillgångar. Om du bara har ett licensavtal för alla dina tillgångar, kan du markera rutan nedan för att använda standardlicensavtalet.',
    'name'                              => 'Kategorinamn',
    'require_acceptance'				=> 'Kräv att användare bekräftar mottagande av tillgångar i denna kategori.',
    'required_acceptance'				=> 'Användaren kommer att få e-post med en länk för att bekräfta mottagande av detta objekt.',
    'required_eula'						=> 'Användaren kommer att få e-post med en kopia av licensavtalet, EULA',
    'no_default_eula'					=> 'Ingen standard-licensavtal, EULA, hittades. Lägg till en under Inställningar.',
    'update'  							=> 'Uppdatera kategori',
    'use_default_eula'					=> 'Använd <a href="#" data-toggle="modal" data-target="#eulaModal">standard-licensavtal, EULA</a> istället.',
    'use_default_eula_disabled'			=> '<del>Använd den primära licensavtalet, EULA:n, istället.</del> Inget primärt licensavtal, EULA, är satt. Vänligen lägg till en under Inställningar.',
    'use_default_eula_column'			=> 'Använd standard-EULA',

);
